## [How can I estimate coefficient standard errors when using ridge regression?](http://stats.stackexchange.com/questions/2121/how-can-i-estimate-coefficient-standard-errors-when-using-ridge-regression)

I think boostrap would the best option to obtain robust SEs. This was done in some applied work using shrinkage methods, e.g. [Analysis of North American Rheumatoid Arthritis Consortium data using a penalized logistic regression approach][1] (BMC Proceedings 2009).
There is also a nice paper from Casella on SE computation with penalized model, [Penalized Regression, Standard Errors, and Bayesian Lassos][2] (Bayesian Analysis 2010 5(2)). But they are more concerned with *lasso* and *elasticnet* penalization.

I always thought of ridge regression as a way to get better predictions than standard OLS, where the model is generally not parcimonious. For variable selection, the *lasso* or *elasticnet* criteria are more appropriate, but then it is difficult to apply a bootstrap procedure (since selected variables would change from one sample to the other, and even in the inner $k$-fold loop used to optimize the $\ell_1$/$\ell_2$ parameters); this is not the case with ridge regression, since you always consider all variables. 

I have no idea about R packages that would give this information. It doesn't seem to be available in the [glmnet][3] package (see Friedman's paper in JSS, [Regularization Paths for Generalized Linear Models via Coordinate Descent][4]).
However, Jelle Goeman who authored the [penalized][5] package discuss this point too. Cannot find the original PDF on the web, so I simply quote his words:

> It is a very natural question to ask
> for standard errors of regression
> coefficients or other estimated
> quantities. In principle such standard
> errors can easily be calculated, e.g.
> using the bootstrap.
>
> Still, this
> package deliberately does not provide
> them. The reason for this is that
> standard errors are not very
> meaningful for strongly biased
> estimates such as arise from penalized
> estimation methods. Penalized
> estimation is a procedure that reduces
> the variance of estimators by
> introducing substantial bias. The bias
> of each estimator is therefore a major
> component of its mean squared error,
> whereas its variance may contribute
> only a small part. 
>
> Unfortunately, in
> most applications of penalized
> regression it is impossible to obtain
> a sufficiently precise estimate of the
> bias. Any bootstrap-based cal-
> culations can only give an assessment
> of the variance of the estimates.
> Reliable estimates of the bias are
> only available if reliable unbiased
> estimates are available, which is
> typically not the case in situations
> in which penalized estimates are used.
>
> Reporting a standard error of a
> penalized estimate therefore tells
> only part of the story. It can give a
> mistaken impression of great
> precision, completely ignoring the
> inaccuracy caused by the bias. It is
> certainly a mistake to make confidence
> statements that are only based on an
> assessment of the variance of the
> estimates, such as bootstrap-based
> confidence intervals do.


  [1]: http://www.biomedcentral.com/1753-6561/3/S7/S61
  [2]: http://j.mp/c3c4tC
  [3]: http://cran.r-project.org/web/packages/glmnet/index.html
  [4]: http://www.jstatsoft.org/v33/i01/paper
  [5]: http://cran.r-project.org/web/packages/penalized/index.html
