## [How to calculate the “exact confidence interval” for relative risk?](http://stats.stackexchange.com/questions/1531/how-to-calculate-the-exact-confidence-interval-for-relative-risk)

Check out the R [Epi][1] and [epitools][2] packages, which include many functions for computing exact and approximate CIs/p-values for various measures of association found in epidemiological studies, including relative risk (RR). I know there is also [PropCIs][3], but I never tried it. Bootstraping is also an option, but generally these are exact or approximated CIs that are provided in epidemiological papers, although most of the explanatory studies rely on GLM, and thus make use of odds-ratio (OR) instead of RR (although, wrongly it is often the RR that is interpreted because it is easier to understand, but this is another story).

You can also check your results with online calculator, like on [statpages.org][7], or [Relative Risk and Risk Difference Confidence Intervals][8]. The latter explains how computations are done.

By "exact" tests, we generally mean tests/CIs not relying on an asymptotic distribution, like the chi-square or standard normal; e.g. in the case of an RR, an 95% CI may be approximated as
$\exp\left[ \log(\text{rr}) - 1.96\sqrt{\text{Var}\big(\log(\text{rr})\big)} \right], \exp\left[ \log(\text{rr}) + 1.96\sqrt{\text{Var}\big(\log(\text{rr})\big)} \right]$, 
where $\text{Var}\big(\log(\text{rr})\big)=1/a - 1/(a+b) + 1/c - 1/(c+d)$ (assuming a 2-way cross-classification table, with $a$, $b$, $c$, and $d$ denoting cell frequencies). The explanations given by @Keith are, however, very insightful. 

For more details on the calculation of CIs in epidemiology, I would suggest to look at Rothman and Greenland's textbook, [Modern Epidemiology][4] (now in it's 3rd edition), [Statistical Methods for Rates and Proportions][5], from Fleiss et al., or [Statistical analyses of the relative risk][6], from J.J. Gart (1979). 

You will generally get similar results with `fisher.test()`, as pointed by @gd047, although in this case this function will provide you with a 95% CI for the odds-ratio (which in the case of a disease with low prevalence will be very close to the RR).

**Notes:** 

1. I didn't check your Excel file, for the reason advocated by @csgillespie.
2. Michael E Dewey provides an interesting summary of [confidence intervals for risk ratios][9], from a digest of posts on the R mailing-list.


  [1]: http://cran.r-project.org/web/packages/Epi/index.html
  [2]: http://cran.r-project.org/web/packages/epitools/index.html
  [3]: http://cran.r-project.org/web/packages/PropCIs
  [4]: http://www.lww.com/product/?978-0-7817-5564-1
  [5]: http://www.wiley.com/remtitle.cgi?0471526290
  [6]: http://www.ncbi.nlm.nih.gov/pmc/articles/PMC1637917/
  [7]: http://statpages.org/ctab2x2.html
  [8]: http://www.phsim.man.ac.uk/risk/
  [9]: http://www.zen103156.zen.co.uk/rr.pdf
