## [When is it acceptable to collapse across groups when performing a factor analysis?](http://stats.stackexchange.com/questions/2259/when-is-it-acceptable-to-collapse-across-groups-when-performing-a-factor-analysis)

There seems to be two cases to consider, depending on whether your scale was already validated using standard psychometric methods (from classical test or item response theory). In what follows, I will consider the first case where I assume preliminary studies have demonstrated construct validity and scores reliability for your scale.

In this case, there is no formal need to apply exploratory factor analysis, unless you want to examine the pattern matrix within each group (but I generally do it, just to ensure that there are no items that unexpectedly highlight low factor loading or cross-load onto different factors); in order to be able to pool all your data, you need to use a multi-group factor analysis (hence, a confirmatory approach as you suggest), which basically amount to add extra parameters for testing a group effect on factor loading (1st order model) or factor correlation (2nd order model, if this makes sense) which would impact measurement invariance across subgroups of respondents. This can be done using [Mplus][1] (see the discussion about CFA [there][2]) or [Mx][3] (e.g. [Conor et al.][4], 2009), not sure about [Amos][5] as it seems to be restricted to simple factor structure. The Mx software has been redesigned to work within the R environment, [OpenMx][6]. The wiki is well responding so you can ask questions if you encounter difficulties with it. There is also a more recent package, [lavaan][7], which appears to be a promising package for SEMs.

Alternatives models coming from IRT may also be considered, including a Latent Regression Rasch Model (for each scale separately, see De Boeck and Wilson, 2004), or a Multivariate Mixture Rasch Model (von Davier and Carstensen, 2007). You can take a look at [Volume 20][8] of the [Journal of Statistical Software][9], entirely devoted to psychometrics in R, for further information about IRT modeling with R.
You may be able to reach similar tests using Structural Equation Modeling, though. 

If factor structure proves to be equivalent across the two groups, then you can aggregate the scores (on your four summated scales) and report your statistics as usual. 
However, it is always a challenging task to use CFA since not rejecting H0 does by no mean allow you to check that your postulated theoretical model is correct in the true world, but just that there is no reason to reject it on statistical grounds; on the other hand, rejecting the null would lead to accept the alternative, which is generally left unspecified, unless you apply sequential testing of nested models. Anyway, this is the way we go in cross-cultural settings, especially when we want to assess whether a given questionnaire (e.g., on Patients Reported Outcomes) measures what it purports to do whatever the population it is administered to.

Now, regarding the apparent differences between the two groups -- one is drawn from a population of students, the other is a clinical sample, assessed at a later date -- it depends very much on your own considerations: Does mixing of these two samples makes sense from the literature surrounding the questionnaire used (esp., it should have shown temporal stability and applicability in a wide population), do you plan to generalize your findings over a larger population (obviously, you gain power by increasing sample size). At first sight, I would say that you need to ensure that both groups are comparable with respect to the characteristics thought to influence one's score on this questionnaire (e.g., gender, age, SES, biomedical history, etc.), and this can be done using classical statistics for two-groups comparison (on raw scores). It is worth noting that in clinical studies, we face the reverse situation: We usually want to show that scores differ between different clinical subgroups (or between treated and naive patients), which is often refered to as *know-group validity*.


**Reference:**

1. De Boeck, P. and Wilson, M. (2004). *Explanatory Item Response Models. A Generalized Linear and Nonlinear Approach*. Springer.
2. von Davier, M. and Carstensen, C.H. (2007). *Multivariate and Mixture Distribution Rasch Models*. Springer.


  [1]: http://www.statmodel.com/
  [2]: http://www.statmodel.com/discussion/messages/9/9.html
  [3]: http://www.vcu.edu/mx/
  [4]: http://www.eric.ed.gov:80/ERICWebPortal/search/detailmini.jsp?_nfpb=true&_&ERICExtSearch_SearchValue_0=EJ857035&ERICExtSearch_SearchType_0=no&accno=EJ857035
  [5]: http://www.spss.com/amos/
  [6]: http://openmx.psyc.virginia.edu/
  [7]: http://lavaan.ugent.be/
  [8]: http://www.jstatsoft.org/index.php?vol=20
  [9]: http://www.jstatsoft.org/
