## [Clustering with a distance matrix](http://stats.stackexchange.com/questions/2717/clustering-with-a-distance-matrix)

One way to highlight clusters on your distance matrix is by way of [Multidimensional scaling][1]. When projecting individuals (here what you call your nodes) in an 2D-space, it provides a comparable solution to PCA. This is unsupervised, so you won't be able to specify a priori the number of clusters, but I think it may help to quickly summarize a given distance or similarity matrix.

Here is what you would get with your data:

    tmp <- matrix(c(0,20,20,20,40,60,60,60,100,120,120,120,
                    20,0,20,20,60,80,80,80,120,140,140,140,
                    20,20,0,20,60,80,80,80,120,140,140,140,
                    20,20,20,0,60,80,80,80,120,140,140,140,
                    40,60,60,60,0,20,20,20,60,80,80,80,
                    60,80,80,80,20,0,20,20,40,60,60,60,
                    60,80,80,80,20,20,0,20,60,80,80,80,
                    60,80,80,80,20,20,20,0,60,80,80,80,
                    100,120,120,120,60,40,60,60,0,20,20,20,
                    120,140,140,140,80,60,80,80,20,0,20,20,
                    120,140,140,140,80,60,80,80,20,20,0,20,
                    120,140,140,140,80,60,80,80,20,20,20,0),
                  nr=12, dimnames=list(LETTERS[1:12], LETTERS[1:12]))
    d <- as.dist(tmp)
    mds.coor <- cmdscale(d)
    plot(mds.coor[,1], mds.coor[,2], type="n", xlab="", ylab="")
    text(jitter(mds.coor[,1]), jitter(mds.coor[,2]),
         rownames(mds.coor), cex=0.8)
    abline(h=0,v=0,col="gray75")

![mds][2]

I added a small jittering on the x and y coordinates to allow distinguishing cases. Replace `tmp` by `1-tmp` if you'd prefer working with dissimilarities, but this yields essentially the same picture. However, here is the hierarchical clustering solution, with *single* agglomeration criteria:

    plot(hclust(dist(1-tmp), method="single"))

![hc][3]

You might further refine the selection of clusters based on the dendrogram, or more robust methods, see e.g. this related question: [What stop-criteria for agglomerative hierarchical clustering are used in practice?][4]


  [1]: http://en.wikipedia.org/wiki/Multidimensional_scaling
  [2]: http://i.imgur.com/oA1vV.png
  [3]: http://i.imgur.com/mOKiI.png
  [4]: http://stats.stackexchange.com/questions/2597/what-stop-criteria-for-agglomerative-hierarchical-clustering-are-used-in-practice
