## [Differences between tetrachoric and Pearson correlation](http://stats.stackexchange.com/questions/3086/differences-between-tetrachoric-and-pearson-correlation)

My best bet is that you are facing large imbalance between your categories responses, for some of your items.

If you assume that your binary responses reflect individual locations on an underlying latent (i.e. continuous) trait, then correlating the two variables is ok, provided the cutoff is close to the mean of the bivariate density, as shown below (here the cutoff are set symmetrically at $(.5,.5)$, for a correlation of 0.5):

![alt text][1]


In this case, the Person correlation will underestimate the true linear relationships between the two latent traits, especially in the mid-range of the correlation metric. On the other hand, when the cutoffs are clearly assymmetrical on both continuous variables, the tetrachoric correlation will generally overestimate the true relationship. The following picture illustrates the ideal case.


    library(polycor)
    set.seed(101)
    n <- 500
    rho <- seq(0,1,length=500)
    pc1 <- pc2 <- tc <- numeric(500)
    
    for (i in 1:500) {
      data <- rmvnorm(n, c(0, 0), matrix(c(1, rho[i], rho[i], 1), 2, 2))
      x <- data[,1]; y <- data[,2]
      xb <- ifelse(x>=mean(x), 1, 0); yb <- ifelse(y>=mean(y), 1, 0)
      pc1[i] <- cor(x, y)
      pc2[i] <- cor(xb, yb)
      tc[i] <- polychor(xb, yb)
    }
    
    plot(pc1, pc2, cex=.6, col="red", xlab="True linear relationship",
         ylab="Observed correlation")
    lines(lowess(pc1, pc2), col="red", lwd=2)
    abline(0, 1, col="lightgray")
    points(pc1, tc, cex=.6, col="blue")
    lines(lowess(pc1, tc), col="blue", lwd=2)
    legend("topleft", c("Pearson (0/1)","Tetrachoric"), col=c(2,4), lty=1, bty="n")


![alt text][2]

Now, you can play with the choice of the cutoff, $\tau$, and see what happens when it is asymmetric and largely departs from the mean of the joint density of $x$ and $y$.

To complement @shabbychef's response, the phi coefficient is generally used with "truly" categorical variables (no hypothesis about a continuous generating process are made) and reduces to Pearson correlation in this case ($\sqrt{\chi^2}/n$). The problem is then to factor out a correlation matrix constructed in such a way because communalities become meaningless.

To avoid this problem, we may rely on parametric item response modeling, e.g. mixed-effects logistic model (in this case, no need to worry about the cutoff, since it is estimated), or non-parametric model, like Mokken scaling; in this latest case, we only assume monotonicity on the latent trait, but no functional form relating one's location on the latent trait and the outcome (i.e. the probability of endorsing the item). However, in your case, it would be a pain and would not allow you to identify a structure in your correlation matrix. But it may be used afterwards.

Finally, John Uebersax provides an in-depth discussion of tetrachoric correlation in relation of latent trait modeling, see [Introduction to the Tetrachoric and Polychoric Correlation Coefficients][3]. Also, Nunnally discussed a long ago of the advantages/disadvantages of relying on Pearson vs. Tetrachoric correlation coefficients in Factor Analysis, see e.g. pp. 570-573 (3rd ed.).

**References**

1. O'Connor, B. [Cautions Regarding Item-Level Factor Analyses][4].
2. Bernstein, I.H., Teng, G. (1989). Factoring items and factoring scales are different: Spurious evidence for multidimensionality due to item categorization. *Psychological Bulletin*, *105*, 467-477.
3. Edwards, J.H. and Edwards, A.W.F. (1984). Approximating the tetrachoric correlation coefficient. *Biometrics*, *40*, 563.
4. Castellan, N.J. (1966). On the estimation of the tetrachoric correlation coefficient. *Psychometrika*, *31(1)*, 67-73. 
5. Fitzgerald, P., Knuiman, M.W., Divitini, M.L., and Bartholomew, H.C. (1999). Effect of dichotomising a continuous variable on the assessment of familial aggregation: an empirical study using body mass index data from the Busselton Health Study. *J. Epidemiol. Biostat.*, *4(4)*, 321-327.
6. Nunnally, J.C. and Bernstein, I.H. (1994). *Psychometric Theory* (Third ed.). McGraw-Hill.


  [1]: http://i.imgur.com/ceUmY.png
  [2]: http://i.imgur.com/FZ14p.png
  [3]: http://www.john-uebersax.com/stat/tetra.htm
  [4]: https://people.ok.ubc.ca/brioconn/nfactors/itemanalysis.html
