## [How to efficiently manage a statistical analysis project?](http://stats.stackexchange.com/questions/2910/how-to-efficiently-manage-a-statistical-analysis-project)

I am compiling a quick series of guidelines I found on [SO][1] (as suggested by @Shane), [Biostar][2] (hereafter, BS), and this SE. I tried my best to acknowledge ownership for each item, and to select first or highly upvoted answer. I also added things of my own, and flagged items that are specific to the [R] environment.

**Data management**

* create a project structure for keeping all things at the right place (data, code, figures, etc., [giovanni][3] /BS)
* never modify raw data files (ideally, they should be read-only), copy/rename to new ones when making transformations, cleaning, etc. 
* check data consistency ([whuber][4] /SE)

**Coding**

* organize source code in logical units or building blocks ([Josh Reich][5]/[hadley][6]/[ars][7] /SO; [giovanni][8]/[Khader Shameer][9] /BS)
* separate source code from editing stuff, especially for large project -- partly overlapping with previous item and reporting
* document everything, with e.g. [R]oxygen ([Shane][10] /SO) or consistent self-annotation in the source file -- a good discussion on Medstats, [Documenting analyses and data edits Options][11]
* [R] custom functions can be put in a dedicated file (that can be sourced when necessary), in a new environment (so as to avoid populating the top-level namespace, [Brendan OConnor][12] /SO), or a package ([Dirk Eddelbuettel][13]/[Shane][14] /SO)

**Analysis**

* don't forget to set/record the seed you used when calling RNG or stochastic algorithms (e.g. k-means)
* for Monte Carlo studies, it may be interesting to store specs/parameters in a separate file ([sumatra][15] may be a good candidate, [giovanni][16] /BS)
* don't limit yourself to one plot per variable, use multivariate (Trellis) displays and interactive visualization tools (e.g. GGobi)

**Versioning**

* use some kind of CVS for easy tracking/export, e.g. Git ([Sharpie][17]/[VonC][18]/[JD Long][19] /SO) -- this follows from nice questions asked by @Jeromy and @Tal
* backup everything, on a regular basis ([Sharpie][20]/[JD Long][21] /SO)
* keep a log of your ideas, or rely on an issue tracker, like [ditz][22] ([giovanni][23] /BS) -- partly redundant with the previous item since it is available in Git

**Editing/Reporting**

* [R] Sweave ([Matt Parker][24] /SO)
* [R] brew ([Shane][25] /SO)
* [R] [R2HTML][26] or [ascii][27]

As a side note, Hadley Wickham offers a comprehensive overview of [R project management][28], including *reproducible exemplification* and an *unified philosophy of data*.


  [1]: http://www.stackoverflow.com
  [2]: http://biostar.stackexchange.com/
  [3]: http://biostar.stackexchange.com/questions/822/how-do-you-manage-your-files-directories-for-your-projects/826#826
  [4]: http://stats.stackexchange.com/questions/2768/what-is-a-consistency-check/2785#2785
  [5]: http://stackoverflow.com/questions/1429907/workflow-for-statistical-analysis-and-report-writing/1434424#1434424
  [6]: http://stackoverflow.com/questions/1429907/workflow-for-statistical-analysis-and-report-writing/1430569#1430569
  [7]: http://stackoverflow.com/questions/1266279/how-to-organize-large-r-programs/1269808#1269808
  [8]: http://biostar.stackexchange.com/questions/822/how-do-you-manage-your-files-directories-for-your-projects/826#826
  [9]: http://biostar.stackexchange.com/questions/822/how-do-you-manage-your-files-directories-for-your-projects/829#829
  [10]: http://stackoverflow.com/questions/2284446/organizing-r-source-code/2284486#2284486
  [11]: http://groups.google.com/group/medstats/browse_thread/thread/601793e6ce36e789
  [12]: http://stackoverflow.com/questions/1266279/how-to-organize-large-r-programs/1319786#1319786
  [13]: http://stackoverflow.com/questions/1266279/how-to-organize-large-r-programs/1266400#1266400
  [14]: http://stackoverflow.com/questions/2284446/organizing-r-source-code/2284486#2284486
  [15]: http://neuralensemble.org/trac/sumatra
  [16]: http://biostar.stackexchange.com/questions/822/how-do-you-manage-your-files-directories-for-your-projects/826#826
  [17]: http://stackoverflow.com/questions/2712421/r-and-version-control-for-the-solo-data-analyst/2715569#2715569
  [18]: http://stackoverflow.com/questions/2545765/how-can-i-email-someone-a-git-repository/2545784#2545784
  [19]: http://stackoverflow.com/questions/2286831/how-do-you-combine-revision-control-with-workflow-for-r/2290194#2290194
  [20]: http://stackoverflow.com/questions/2712421/r-and-version-control-for-the-solo-data-analyst/2715569#2715569
  [21]: http://stackoverflow.com/questions/2286831/how-do-you-combine-revision-control-with-workflow-for-r/2290194#2290194
  [22]: http://ditz.rubyforge.org/ditz/
  [23]: http://biostar.stackexchange.com/questions/822/how-do-you-manage-your-files-directories-for-your-projects/826#826
  [24]: http://stackoverflow.com/questions/1429907/workflow-for-statistical-analysis-and-report-writing/1430013#1430013
  [25]: http://stackoverflow.com/questions/1429907/workflow-for-statistical-analysis-and-report-writing/1436809#1436809
  [26]: http://cran.r-project.org/web/packages/R2HTML/index.html
  [27]: http://cran.r-project.org/web/packages/ascii/index.html
  [28]: http://github.com/hadley/devtools/wiki
  [29]: http://github.com/hadley/devtools/wiki/Reproducibility
