## [Interpreting PCA scores](http://stats.stackexchange.com/questions/4093/interpreting-pca-scores)

Basically, the factor scores are computed as the raw responses weighted by the factor loadings. So, you need to look at the factor loadings of your first dimension to see how each variable relate to the principal component. Observing high positive (resp. negative) loadings associated to specific variables means that these variables contribute positively (resp. negatively) to this component; hence, people scoring high on these variables will tend to have higher (resp. lower) factor scores on this particular dimension.

Drawing the correlation circle is useful to have a general idea of the variables that contribute "positively" vs. "negatively" (if any) to the first principal axis, but if you are using R you may have a look at the [FactoMineR][1] package and the `dimdesc()` function.

Here is an example with the `USArrests` data:

    > data(USArrests)
    > library(FactoMineR)
    > res <- PCA(USArrests)
    > dimdesc(res, axes=1)  # show correlation of variables with 1st axis
    $Dim.1
    $Dim.1$quanti
             correlation  p.value
    Assault        0.918 5.76e-21
    Rape           0.856 2.40e-15
    Murder         0.844 1.39e-14
    UrbanPop       0.438 1.46e-03
    > res$var$coord  # show loadings associated to each axis
             Dim.1  Dim.2  Dim.3   Dim.4
    Murder   0.844 -0.416  0.204  0.2704
    Assault  0.918 -0.187  0.160 -0.3096
    UrbanPop 0.438  0.868  0.226  0.0558
    Rape     0.856  0.166 -0.488  0.0371

As can be seen from the latest result, the first dimension mainly reflects violent acts (of any kind). If we look at the individual map, it is clear that states located on the right are those where such acts are most frequent.

![alt text][2]
![alt text][3]

You may also be interested in this related question: [What are principal component scores?][4]


  [1]: http://cran.r-project.org/web/packages/FactoMineR/index.html
  [2]: http://i.imgur.com/uOgTV.png
  [3]: http://i.imgur.com/fnp7W.png
  [4]: http://stats.stackexchange.com/questions/222/what-are-principal-component-scores
