## [Automating model selection criteria production](http://stats.stackexchange.com/questions/5550/automating-model-selection-criteria-production)

Ok, here is another way (which is certainly not as elegant or concise than the other ones, but it has the merit of not requiring Emacs to check parenthesis matches :-)

Let's say we have a vector of predictors of interest like this

    > Xs <- paste("X", 1:4, sep="")

Then, we can just use

    > allXs <- lapply(seq(along=Xs), 
                      function(x) combn(Xs, x, simplify=FALSE, 
                                        FUN=paste, collapse="+"))

where 

    > unlist(allXs)

gives you all 15 combinations of the X's.

Another option is to just change the right-hand side of a formula, say 

     fm <- as.formula(paste("Y ~ ", paste(Xs, collapse= "+")))

so as to reflect the different combinations that you enumerate in your `comb_list` object. This can be done using the [Formula][1] package:

    > fm <- as.formula(paste("Y ~ ", paste(Xs, collapse= "|")))
    > fm2 <- Formula(fm)
    > foo <- function(x) formula(fm2, rhs=x, collapse=TRUE)
    > foo(1:2)
    Y ~ X1 + X2
    <environment: 0x102593040>
    > foo(c(1,3,4))
    Y ~ X1 + X3 + X4
    <environment: 0x1021d02a0>


  [1]: http://cran.r-project.org/web/packages/Formula/index.html

