## [Getting started with biclustering](http://stats.stackexchange.com/questions/7419/getting-started-with-biclustering)

I never used it directly, so I can only share some papers I had and general thoughts about that technique (which mainly address your questions 1 and 3).

My general understanding of biclustering mainly comes from genetic studies (2-6) where we seek to account for clusters of genes and grouping of individuals: in short, we are looking to groups samples sharing similar profile of gene expression together (this might be related to disease state, for instance) *and* genes that contribute to this pattern of gene profiling. A survey of the state of the art for biological "massive" datasets is available in Pardalos's slides, [Biclustering][1]. Note that there is an R package, [biclust][2], with applications to microarray data.

In fact, my initial idea was to apply this methodology to clinical diagnosis, because it allows to put features or variables in more than one cluster, which is interesting from a semeiological perpective because symptoms that cluster together allow to define *syndrome*, but some symptoms can overlap in different diseases. A good discussion may be found in Cramer et al., [Comorbidity: A network perspective][3] (Behavioral and Brain Sciences 2010, 33, 137-193). 

A somewhat related technique is *[collaborative filtering][4]*. A good review was made available by Su and Khoshgoftaar (*Advances in Artificial Intelligence*, 2009): [A Survey of Collaborative Filtering Techniques][5]. Other references are listed at the end. Maybe analysis of [frequent itemset][6], as exemplified in the [market-basket problem][7], is also linked to it, but I never investigated this. Another example of co-clustering is when we want to simultaneously cluster words and documents, as in text mining, e.g. Dhillon (2001). [Co-clustering documents and words using bipartite spectral graph partitioning][8]. *Proc. KDD*, pp. 269–274.

About some general references, here is a not very exhaustive list that I hope you may find useful:

1. Jain, A.K. (2010). [Data clustering: 50 years beyond K-means][9]. *Pattern Recognition Letters*, *31*, 651–666
2. Carmona-Saez et al. (2006). [Biclustering of gene expression data by non-smooth non-negative matrix factorization][10]. *BMC Bioinformatics*, *7*, 78.
3. Prelic et al. (2006). [A systematic comparison and evaluation of biclustering methods for gene expression data][11]. *Bioinformatics*, *22(9)*, 1122-1129. [www.tik.ee.ethz.ch/sop/bimax](http://www.tik.ee.ethz.ch/sop/bimax)
4. DiMaggio et al. (2008). [Biclustering via optimal re-ordering of data matrices in systems biology: rigorous methods and comparative studies][12]. *BMC Bioinformatics*, *9*, 458.
5. Santamaria et al. (2008). [BicOverlapper: A tool for bicluster visualization][13]. *Bioinformatics*, *24(9)*, 1212-1213.
6. Madeira, S.C. and Oliveira, A.L. (2004) [Bicluster algorithms for biological data analysis: a survey][14]. *IEEE Trans. Comput. Biol. Bioinform.*, *1*, 24–45.
7. Badea, L. (2009). [Generalized Clustergrams for Overlapping Biclusters][15]. IJCAI
8. Symeonidis, P. (2006). [Nearest-Biclusters Collaborative Filtering][16]. WEBKDD


  [1]: http://www.ise.ufl.edu/cao/DMinAgriculture/Lecture6.biclustering.pdf
  [2]: http://cran.r-project.org/web/packages/biclust/index.html
  [3]: http://sites.google.com/site/borsboomdenny/CramerEtAl2010.pdf?attredirects=0
  [4]: http://en.wikipedia.org/wiki/Collaborative_filtering
  [5]: http://www.hindawi.com/journals/aai/2009/421425.html
  [6]: http://www.albionresearch.com/data_mining/market_basket.php
  [7]: http://www.albionresearch.com/data_mining/market_basket.php
  [8]: http://www.cs.utexas.edu/users/inderjit/public_papers/kdd_bipartite.pdf
  [9]: http://biometrics.cse.msu.edu/Publications/Clustering/JainClustering_PRL10.pdf
  [10]: http://www.biomedcentral.com/1471-2105/7/78
  [11]: http://bioinformatics.oxfordjournals.org/content/22/9/1122.abstract
  [12]: http://www.biomedcentral.com/1471-2105/9/458
  [13]: http://bioinformatics.oxfordjournals.org/content/24/9/1212.abstract
  [14]: http://www.inesc-id.pt/ficheiros/publicacoes/1281.pdf
  [15]: http://ijcai.org/papers09/Papers/IJCAI09-232.pdf
  [16]: http://webmining.spd.louisville.edu/webkdd06/papers/paper-3-Nearest%20Bi-Cluster%20CF_SymeonidiswebKDD06.pdf
