## [Is there an R package with a pretty function that can deal effectively with outliers?](http://stats.stackexchange.com/questions/11620/is-there-an-r-package-with-a-pretty-function-that-can-deal-effectively-with-outli)

If you're importing your data with a command like, say,

    read.table('yourfile.txt', header=TRUE, ...)

you can indicate what values are to be considered as "null" or `NA` values, by specifying `na.strings = "999999999"`. We can also consider different values for indicating `NA` values. Consider the following file (`fake.txt`) where we want to treat "." and "999999999" as NA values:

    1 2 .
    3 999999999 4
    5 6 7

then in R we would do:

    > a <- read.table("fake.txt", na.strings=c(".","999999999"))
    > a
      V1 V2 V3
    1  1  2 NA
    2  3 NA  4
    3  5  6  7

Otherwise, you can always filter your data as indicated by @Sacha in his comment. Here, it could be something like

    a[a=="." | a==999999999] <- NA

**Edit**

In case there are multiple abnormal values that can possibly be observed in different columns with different values, *but you know the likely range of admissible values*, you can apply a function to each column. For example, define the following filter:

    my.filter <- function(x, threshold=100) ifelse(x > threshold, NA, x)

then 

    a.filt <- apply(a, 2, my.filter)

will replace every value > 100 with NA in the matrix `a`.

*Example:*

    > a <- replicate(10, rnorm(10))
    > a[1,3] <- 99999999
    > a[5,6] <- 99999999
    > a[8,10] <- 99999990
    > summary(a[,3])
       Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
     -1e+00   0e+00   0e+00   1e+07   1e+00   1e+08 
    > af <- apply(a, 2, my.filter)
    > summary(af[,3])
       Min. 1st Qu.  Median    Mean 3rd Qu.    Max.    NA's 
    -1.4640 -0.2680  0.4671 -0.0418  0.4981  0.7444  1.0000 

It can be vector-based of course:

    > summary(my.filter(a[,3], 500))
       Min. 1st Qu.  Median    Mean 3rd Qu.    Max.    NA's 
    -1.4640 -0.2680  0.4671 -0.0418  0.4981  0.7444  1.0000 
