## [Determining the variables when training a/classifying with a random forest](http://stats.stackexchange.com/questions/15076/determining-the-variables-when-training-a-classifying-with-a-random-forest)

As requested, I'll turn my comment to an answer, although I doubt it
will provide you with a working solution. 

The Random Forest&#8482; algorithm is well described on [Breiman's
webpage][1]. See references therein. Basically, it relies on the idea of [*bagging*][2]
(bootstrap aggregation) where we "average" the results of one (or
more) classifier run over different subsamples of the original
dataset (1). This is part of what we called more generally [*ensemble
learning*][3]. The advantage of this approach is that it allows to
keep a "training" sample (approx. 2/3 when sampling with replacement)
to build the classifier, and a "validation" sample to evaluate its
performance; the latter is also known as the out-of-bag (OOB)
sample. Classification and regression trees (CART, e.g. (2)) work generally well
within this framework, but it is worth noting that in this particular case we do not want to prune the tree (to avoid [overfitting][4]; on the contrary, we deliberately choose to work with "weak" classifiers). By
constructing several models and combining their individual estimates
(most of the times, by a majority vote), we introduce some kind of
variety, or fluctuations, in model outputs, while at the same time we
circumvent the decision of a single weak classifier by averaging over
a collection of such decisions. The [ESLII textbook][5] (3) has a full chapter devoted to such techniques.

However, in RF there is a second level of randomization, this time at
the level of the variables: only random subsets of the original
variables are considered when growing a tree, typically $\sqrt{p}$,
where $p$ is the number of predictors. This means that RF can work
with a lot more variables than other traditional methods, especially
those where we expect to have more observations than variables. In
addition, this technique will be less impacted by collinearity
(correlation between the predictors). Finally, subsampling the
predictors has for a consequence that the fitted values across trees
are more independent.

As depicted in the next figure, let's consider a block of predictors
$X$ ($n\times p$) and a response vector $Y$, of length $n$, which
stands for the outcome of interest (it might be a binary or numerical
variable). 

![enter image description here][6]

Here, we'll be considering a classification task ($Y$ is
categorical). The three main steps are as follows:

1. Take a random sample of the $n$ individuals; they will be used to
build a single tree.
2. Select $k<p$ variables and find the first split; *iterate* until the
full tree is grown (do not prune); drop the OOB data down the tree and
record the outcome assigned to each observation.

Do steps 1--2 $b$ times (say, $b=500$), and each time count the number
of times each individual from the OOB sample is classified into one
category or the other. Then assign each case a category by using a
majority vote over the $b$ trees. You have your predicted outcomes. 

In order to
assess *variable importance*, that is how much a variable contributes
to classification accuracy, we could estimate the extent to which the
predictions would be affected if there were no association between the
outcome and the given variable. An obvious way to do this is to
shuffle the individual labels (this follows from the principle of
[re-randomization][7]), and compute the difference in predictive
accuracy with the original model. This is step 3. The more predictive
a variable is (when trying to predict a future outcome--this really is
forecasting, because remember that we only use our OOB sample for assessing
the predictive ability of our model), the more likely the
classification accuracy will decrease when breaking the link between
its observed values and the outcome.

-----------

Now, about your question, 

* Reliable ways to assess the importance of your predictors have been proposed in the past (this might be the one described above, or additional resampling strategy related to backward elimination (4,5)); so there's no need to reinvent the wheel.
* The hard task, IMO, is to choose your descriptors or features, that is the characteristics of your records. Note that it should not be specific to a subset of your units, but rather encompasses a general description of possible events, e.g. "One Shot Game" vs. other (I'm not very good at game :-). 
* Do an extensive literature search on what has been carried out in this direction on this specific field. 
* Do not break the control on overfitting that is guaranteed by RF by running additional feature selection + new classification tasks *on the same sample*.

If you're interested in knowing more about RF, there's probably a lot of [additional information](http://stats.stackexchange.com/questions/tagged/random-forest) on this site, and currently available implementations of RF have been listed [here][8]. 

## References

1. Sutton, C.D. (2005). [Classification and Regression Trees, Bagging, and Boosting][9], in *Handbook of Statistics*, Vol. 24, pp. 303-329, Elsevier.
2. Moissen, G.G. (2008). [Classification and Regression Trees][10]. *Ecological Informatics*, pp. 582-588.
3. Hastie, T., Tibshirani, R., and Friedman, J. (2009). [*The Elements of 
Statistical Learning: Data Mining, Inference, and Prediction (2nd ed.)*][11]. Springer.
4. Díaz-Uriarte, R., Alvarez de Andrés, S. (2006). [Gene selection and classification of microarray data using Random Forest][12]. *BMC Bioinformatics*, 7:3.
5. Díaz-Uriarte, R. (2007). [GeneSrF and varSelRF: a web-based tool and R package for gene selection and classification using Random Forest][13]. *BMC Bioinformatics*, 8:328.


  [1]: http://www.stat.berkeley.edu/~breiman/RandomForests/cc_home.htm
  [2]: http://en.wikipedia.org/wiki/Bootstrap_aggregating
  [3]: http://en.wikipedia.org/wiki/Ensemble_learning
  [4]: http://en.wikipedia.org/wiki/Overfitting
  [5]: http://www-stat.stanford.edu/~tibs/ElemStatLearn/
  [6]: http://i.stack.imgur.com/o5Kd1.png
  [7]: http://i.stack.imgur.com/o5Kd1.png
  [8]: http://stats.stackexchange.com/questions/10001/implementations-of-the-random-forest-algorithm/10028#10028
  [9]: http://www.biostat.jhsph.edu/~ririzarr/Teaching/649/section-11.pdf
  [10]: http://www.fs.fed.us/rm/pubs_other/rmrs_2008_moisen_g001.pdf
  [11]: http://www-stat.stanford.edu/~tibs/ElemStatLearn/
  [12]: http://www.biomedcentral.com/1471-2105/7/3/abstract
  [13]: http://www.biomedcentral.com/1471-2105/8/328
