## [Obtaining random number from a mixture of two normal distributions](http://stats.stackexchange.com/questions/20068/obtaining-random-number-from-a-mixture-of-two-normal-distributions)

If you want to sample unequally (with probability 0.7 and 0.3) from two gaussians with parameters $(\mu_1,\sigma_1^2)$ and $(\mu_2,\sigma_2^2)$, then you can probably try something like that:

    n <- 100
    yn <- rbinom(n, 1, .7)
    # draw n units from a mixture of N(0,1) and N(100,3^2)
    s <- rnorm(n, 0 + 100*yn, 1 + 2*yn)

In fact, this is one of the illustrations provided in *Modern Applied Statistics with S*, by Venables and Ripley (Springer, 2002; §5.2, pp. 110-111).

With different parameters, you can use an `ifelse` expression to select the mean and SD according to the binomial sequence given in `yn`, e.g. `rnorm(n, mean=ifelse(yn, 21, 26), sd=ifelse(yn, 3.3, 4))`. (No need to cast `yn` to a logical with `as.logical`.)
