## [How to apply coefficient term for factors and interactive terms in a linear equation?](http://stats.stackexchange.com/questions/24242/how-to-apply-coefficient-term-for-factors-and-interactive-terms-in-a-linear-equa)

*This is just a comment but it won't fit as such in the limited edit boxes we have at our disposal.*

I like seeing a regression equation clearly written in plain text, as @whuber did in his reply. Here is a quick way to this in R, with the [Hmisc][1] package. (I'll be using [rms][2] too, but that does not really matter.) Basically, it only assumes that a $\LaTeX$ typesetting system is available on your machine.

Let's simulate some data first,

    n <- 200
    x1 <- runif(n)
    x2 <- runif(n)
    x3 <- runif(n)
    g1 <- gl(2, 100, n, labels=letters[1:2])
    g2 <- cut2(runif(n), g=4)
    y <- x1 + x2 + rnorm(200)

then fit a regression model,

    f <- ols(y ~ x1 + x2 + x3 + g1 + g2 + x1:g1)

which yields the following results:

    Linear Regression Model
    
    ols(formula = y ~ x1 + x2 + x3 + g1 + g2 + x1:g1)
    
                    Model Likelihood     Discrimination    
                       Ratio Test           Indexes        
    Obs      200    LR chi2     35.22    R2       0.161    
    sigma 0.9887    d.f.            8    R2 adj   0.126    
    d.f.     191    Pr(> chi2) 0.0000    g        0.487    
    
    Residuals
    
        Min      1Q  Median      3Q     Max 
    -3.1642 -0.7109  0.1015  0.7363  2.7342 
    
                       Coef    S.E.   t     Pr(>|t|)
    Intercept           0.0540 0.2932  0.18 0.8541  
    x1                  1.1414 0.3642  3.13 0.0020  
    x2                  0.8546 0.2331  3.67 0.0003  
    x3                 -0.0048 0.2472 -0.02 0.9844  
    g1=b                0.2099 0.2895  0.73 0.4692  
    g2=[0.23278,0.553)  0.0609 0.1988  0.31 0.7598  
    g2=[0.55315,0.777) -0.2615 0.1987 -1.32 0.1896  
    g2=[0.77742,0.985] -0.2107 0.1986 -1.06 0.2901  
    x1 * g1=b          -0.2354 0.5020 -0.47 0.6396  

Then, to print the corresponding regression equation, just use the generic `latex` function, like this:

    latex(f)

Upon conversion of the dvi to png, you should get something like that

![enter image description here][3]

IMO, this has the merit of showing how to compute predicted values depending on actual or chosen values for numerical and categorical predictors. For the latter, factor levels are indicated in bracket near the corresponding coefficient.


  [1]: http://cran.r-project.org/web/packages/Hmisc/index.html
  [2]: http://cran.r-project.org/web/packages/rms/index.html
  [3]: http://i.stack.imgur.com/RgBvk.png
