## [Scatterplot with contour/heat overlay](http://stats.stackexchange.com/questions/31726/scatterplot-with-contour-heat-overlay)

Here is my take, using base functions only for drawing stuff:


    library(MASS)  # in case it is not already loaded 
    set.seed(101)
    n <- 1000
    X <- mvrnorm(n, mu=c(.5,2.5), Sigma=matrix(c(1,.6,.6,1), ncol=2))
    
    ## some pretty colors
    library(RColorBrewer)
    k <- 11
    my.cols <- rev(brewer.pal(k, "RdYlBu"))
    
    ## compute 2D kernel density, see MASS book, pp. 130-131
    z <- kde2d(X[,1], X[,2], n=50)
    
    plot(X, xlab="X label", ylab="Y label", pch=19, cex=.4)
    contour(z, drawlabels=FALSE, nlevels=k, col=my.cols, add=TRUE)
    abline(h=mean(X[,2]), v=mean(X[,1]), lwd=2)
    legend("topleft", paste("R=", round(cor(X)[1,2],2)), bty="n")

![enter image description here][1]

For more fancy rendering, you might want to have a look at [ggplot2][2] and `stat_density2d()`. Another function I like is `smoothScatter()`:

    smoothScatter(X, nrpoints=.3*n, colramp=colorRampPalette(my.cols), pch=19, cex=.8)

![enter image description here][3]


  [1]: http://i.stack.imgur.com/Cezab.png
  [2]: http://had.co.nz/ggplot2/
  [3]: http://i.stack.imgur.com/05E92.png
