## [Correlation plots with missing values](http://stats.stackexchange.com/questions/32220/correlation-plots-with-missing-values)

It is possible to display complete cases *and* missing values altogether: just assign a pair of artificial values to observations having one missing value, such that they appear, e.g., in the lower left of your display without overlapping with pairwise complete observations (it is also possible to add small perturbations to their coordinates, like random jittering, to avoid overlapping, and use a different color or symbol shape). An alternative solution is to plot missing values in the margin, as shown below (Source: [InfoVis 03 conference](http://www.ggobi.org/book/2007-infovis/03-missing.pdf)):

![enter image description here][1]

In any case, you should work with pairwise complete observations, for visualization purpose, not complete cases on the entire data set.

[Klimt][2] also handles missing values in a nice way as they are displayed along the horizontal (when y-value is missing) and vertical (when x-value is missing) axis, as shown in the following picture.

![enter image description here][3]

Here is a little R function that should handle this:

    miss.value.plot <- function(x, y, ...) {
      plot(x, y, ...)
      rug(jitter(x[is.na(y)], amount=.1), side=1, lwd=1.2)
      rug(jitter(y[is.na(x)], amount=.1), side=2, lwd=1.2)
    }

It can be used as a panel for `pairs` as well: Just replace `plot` with `points`. Of course, you can replace `rug` with `points` if your prefer to draw points or other symbols. In this case, you will have to provide constant values for the x or y complementary coordinates.

It is also possible to rely on software that allows dynamic brushing and linked plots, like [GGobi][4]. Basically, the idea is to have your original data matrix, and a copy of it, only composed of 0's and 1's and coding for missingness. Linking the two tables allows to study relationships between any two variables while looking at pattern of missingness in the other variables. Some of these techniques are discussed in the chapter on [Missing Data][5] from [Interactive and Dynamic Graphics for Data Analysis: With Examples Using R][6] and GGobi, by Cook and Swayne. There is an [R interface][7] that allows to work directly from R. This really is for situations where missing patterns are of interest. See also [MissingDataGUI: A Graphical User Interface for Exploring Missing Values in Data][8].

Another software for interactive scatterplot displays is [Mondrian][9]. (There was also [Manet][10] but I cannot get it to work on my Intel Mac anymore.)


  [1]: http://i.stack.imgur.com/RMvT6.png
  [2]: http://rosuda.org/Klimt/
  [3]: http://i.stack.imgur.com/nx6ry.png
  [4]: http://www.ggobi.org/
  [5]: http://www.ggobi.org/book/chap-miss.pdf
  [6]: http://www.ggobi.org/book/
  [7]: http://cran.r-project.org/web/packages/rggobi/index.html
  [8]: http://www.math.montana.edu/~jimrc/classes/stat506/notes/MissingDataGUI.pdf
  [9]: http://stats.math.uni-augsburg.de/mondrian/
  [10]: http://stats.math.uni-augsburg.de/Manet/
