## [What is the relationship between a chi square test and test of equal proportions?](http://stats.stackexchange.com/questions/2391/what-is-the-relationship-between-a-chi-square-test-and-test-of-equal-proportions)

Very short answer: 

The chi-Square test (`chisq.test()` in R) compares the observed frequencies in each category of a contingency table with the expected frequencies (computed as the product of the marginal frequencies). It is used to determine whether the deviations between the observed and the expected counts are too large to be attributed to chance. Departure from independence is easily checked by inspecting residuals (try `?mosaicplot` or `?assocplot`, but also look at the `vcd` package). Use `fisher.test()` for an exact test (relying on the hypergeometric distribution).

The `prop.test()` function in R allows to test whether proportions are comparable between groups or does not differ from theoretical probabilities. It is refered to as a $z$-test because the statistics looks like

$$
z=(f_1-f_2)/\sqrt{\hat p\big(\frac{1}{n_1}+\frac{1}{n_2}\big)}
$$

where $\hat p=(p_1+p_2)/(n_1+n_2)$, and indices $(1,2)$ refers to the first and second line of your table.
In a two-way contingency table where $H_0:\; p_1=p_2$, this should yield comparable results to the ordinary $\chi^2$ test:

    > tab <- matrix(c(100, 80, 20, 10), ncol = 2)
    > chisq.test(tab)
    
    	Pearson's Chi-squared test with Yates' continuity correction
    
    data:  tab 
    X-squared = 0.8823, df = 1, p-value = 0.3476
    
    > prop.test(tab)
    
    	2-sample test for equality of proportions with continuity correction
    
    data:  tab 
    X-squared = 0.8823, df = 1, p-value = 0.3476
    alternative hypothesis: two.sided 
    95 percent confidence interval:
     -0.15834617  0.04723506 
    sample estimates:
       prop 1    prop 2 
    0.8333333 0.8888889 
 

For analysis of discrete data with R, I highly recommend [R (and S-PLUS) Manual to Accompany Agresti’s Categorical Data Analysis (2002)][1], from Laura Thompson.


  [1]: https://home.comcast.net/~lthompson221/Splusdiscrete2.pdf
