## [Swamy Random Coefficient Model and time fixed effects](http://stats.stackexchange.com/questions/2579/swamy-random-coefficient-model-and-time-fixed-effects)

I think you use Stata, given your other post about [Panel data and selection models issue][1]. Did you look at the following paper, [From the help desk: Swamy’s random-coefficients model][2] from the Stata Journal (2003 3(3))? It seems that the command `xtrchh2` (available through `findit xtrchh` in Stata command line) includes an option about time, but I'm afraid it only allow to estimate the panel-specific coefficients. Looking around, I only found this article, [Estimation and testing of fixed-effect panel-data systems][3] (SJ 2005 5(2)), but it doesn't seem to address your question.
So maybe it is better to use the [xtreg][4] command directly.
If you have more than one random coefficient, then it may be better to [gllamm][5].

Otherwise, I would suggest trying the [plm][6] R package (it has a lot of dependencies, but it mainly relies on the `nlme` and `survival` packages). The `effect` parameter that is passed to `plm()` seems to return individual, time or both (for balanced design) kind of effects; there's also a function names `plstest()`. I'm not a specialist of econometrics, I only used it for clinical trials in the past, but quoting the online help, it seems you will be able to get fixed effects for your time covariate (expressed as deviations from the overall mean or as deviations from the first value of the index):

    library(plm)
    data("Grunfeld", package = "plm")
    gi <- plm(inv ~ value + capital, data = Grunfeld,
              model = "within", effect = "twoways")
    summary(gi)
    fixef(gi,effect = "time")

where the data looks like (or see the plot below to get a rough idea):

        firm year   inv  value capital
      1    1 1935 317.6 3078.5     2.8
      2    1 1936 391.8 4661.7    52.6
      3    1 1937 410.6 5387.1   156.9
    ...
    198   10 1952  6.00  74.42    9.93
    199   10 1953  6.53  63.51   11.68
    200   10 1954  5.12  58.12   14.33

For more information, check the accompagnying vignette or this paper, [Panel Data Econometrics in R: The plm Package][7], published in the JSS (2008 27(2)).

![Grunfeld][8]


  [1]: http://stats.stackexchange.com/questions/2650/panel-data-and-selection-models-issue
  [2]: http://www.stata-journal.com/sjpdf.html?articlenum=st0046
  [3]: http://www.stata-journal.com/article.html?article=st0084
  [4]: http://www.stata.com/help.cgi?xtreg
  [5]: http://www.gllamm.org/
  [6]: http://cran.r-project.org/web/packages/plm/index.html
  [7]: http://www.jstatsoft.org/v27/i02/paper
  [8]: http://i.imgur.com/6V8wi.png
