## [Alternatives to classification trees, with better predictive (e.g: CV) performance?](http://stats.stackexchange.com/questions/3458/alternatives-to-classification-trees-with-better-predictive-e-g-cv-performanc)

I think it would be worth giving a try to Random Forests ([randomForest][1]); some references were provided in response to related questions: [Feature selection for “final” model when performing cross-validation in machine learning][2]; [Can CART models be made robust?][3]. Boosting/bagging render them more stable than a single CART which is known to be very sensitive to small perturbations. Some authors argued that it performed as well as penalized SVM or [Gradient Boosting Machines][4] (see, e.g. Cutler et al., 2009). I think they certainly outperform NNs.

Boulesteix and Strobl provides a nice overview of several classifiers in [Optimal classifier selection and negative bias in error rate estimation: an empirical study on high-dimensional prediction][5] (BMC MRM 2009 9: 85). I've heard of another good study at the [IV EAM meeting][6], which should be under review in *Statistics in Medicine*,

> **João Maroco**, Dina Silva, Manuela Guerreiro, Alexandre de Mendonça. Do
> Random Forests Outperform Neural
> Networks, Support Vector Machines and
> Discriminant Analysis classifiers? A
> case study in the evolution to
> dementia in elderly patients with
> cognitive complaints


I also like the [caret][7] package: it is well documented and allows to compare predictive accuracy of different classifiers on the same data set. It takes care of managing training /test samples, computing accuracy, etc in few user-friendly functions.

The [glmnet][8] package, from Friedman and coll., implements penalized GLM (see the review in the [Journal of Statistical Software][9]), so you remain in a well-known modeling framework.

Otherwise, you can also look for *association rules* based classifiers (see the CRAN Task View on [Machine Learning][10] or the [Top 10 algorithms in data mining][11] for a gentle introduction to some of them).

I'd like to mention another interesting approach that I plan to re-implement in R (actually, it's Matlab code) which is [Discriminant Correspondence Analysis][12] from Hervé Abdi. Although initially developed to cope with small-sample studies with a lot of explanatory variables (eventually grouped into coherent blocks), it seems to efficiently combine classical DA with data reduction techniques.


**References**

1. Cutler, A., Cutler, D.R., and Stevens, J.R. (2009). Tree-Based Methods, in *High-Dimensional Data Analysis in Cancer Research*, Li, X. and Xu, R. (eds.), pp. 83-101, Springer.
2. Saeys, Y., Inza, I., and Larrañaga, P. (2007). [A review of feature selection techniques in bioinformatics][13]. Bioinformatics, 23(19): 2507-2517.


  [1]: http://cran.r-project.org/web/packages/randomForest/index.html
  [2]: http://stats.stackexchange.com/questions/2306/feature-selection-for-final-model-when-performing-cross-validation-in-machine-l/2307#2307
  [3]: http://stats.stackexchange.com/questions/2410/can-cart-models-be-made-robust
  [4]: http://en.wikipedia.org/wiki/Gradient_boosting
  [5]: http://www.biomedcentral.com/1471-2288/9/85/
  [6]: http://www.iqb.hu-berlin.de/veranst/EAM-SMABS
  [7]: http://caret.r-forge.r-project.org/Classification_and_Regression_Training.html
  [8]: http://cran.r-project.org/web/packages/glmnet/index.html
  [9]: http://www.jstatsoft.org/v33/i01/
  [10]: http://cran.r-project.org/web/views/MachineLearning.html
  [11]: http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.144.5575&rep=rep1&type=pdf
  [12]: http://www.utdallas.edu/~herve/abdi-wafo2010-mudica-inpress.pdf
  [13]: http://bioinformatics.oxfordjournals.org/content/23/19/2507.abstract
