## [Best practice when analysing pre-post treatment-control designs](http://stats.stackexchange.com/questions/3466/best-practice-when-analysing-pre-post-treatment-control-designs)

There is a huge literature around this topic (change/gain scores), and I think the best references come from the biomedical domain, e.g. 

> Senn, S (2007). *Statistical issues in
> drug development*. Wiley (chap. 7 pp.
> 96-112)

In biomedical research, interesting work has also been done in the study of [cross-over trials][1] (esp. in relation to *carry-over* effects, although I don't know how applicable it is to your study).

[From Gain Score t to ANCOVA F (and vice versa)][2], from Knapp & Schaffer, provides an interesting review of ANCOVA vs. t approach (the so-called Lord's Paradox). The simple analysis of change scores is not the recommended way for pre/post design according to Senn  in his article [Change from baseline and analysis of covariance revisited][3] (Stat. Med. 2006 25(24)). Moreover, using a mixed-effects model (e.g. to account for the correlation between the two time points) is not better because you really need to use the "pre" measurement as a covariate to increase precision (through adjustment). Very briefly:

* The use of change scores (post $-$ pre, or outcome $-$ baseline) does not solve the problem of imbalance; the correlation between pre and post measurement is < 1, and the correlation between pre and (post $-$ pre) is generally negative -- it follows that if the treatment (your group allocation) as measured by raw scores happens to be an unfair disadvantage compared to control, it will have an unfair advantage with change scores.
* The variance of the estimator used in ANCOVA is generally lower than that for raw or change scores (unless correlation between pre and post equals 1).
* If the pre/post relationships differ between the two groups (slope), it is not as much of a problem than for any other methods (the change scores approach also assumes that the relationship is identical between the two groups -- the parallel slope hypothesis).
* Under the null hypothesis of equality of treatment (on the outcome), no interaction treatment x baseline is expected; it is dangerous to fit such a model, but in this case one must use centered baselines (otherwise, the treatment effect is estimated at the covariate origin).

I also like [Ten Difference Score Myths][4] from Edwards, although it focuses on difference scores in a different context; but here is an [annotated bibliography][5] on the analysis of pre-post change (unfortunately, it doesn't cover very recent work). Van Breukelen also compared ANOVA vs. ANCOVA in randomized and non-randomized setting, and his conclusions support the idea that ANCOVA is to be preferred, at least in randomized studies (which prevent from regression to the mean effect).


  [1]: http://en.wikipedia.org/wiki/Crossover_study
  [2]: http://pareonline.net/pdf/v14n6.pdf
  [3]: http://onlinelibrary.wiley.com/doi/10.1002/sim.2682/abstract
  [4]: http://public.kenan-flagler.unc.edu/faculty/edwardsj/Edwards01b.pdf
  [5]: http://www.ori.org/~keiths/bibliography/statistics-prepost.html
