## [Statistics and data mining software tools for dealing with large datasets](http://stats.stackexchange.com/questions/3595/statistics-and-data-mining-software-tools-for-dealing-with-large-datasets)

I'll second @suncoolsu comment: The dimensionality of your data set is not the only criterion that should orient you toward a specific software. For instance, if you're just planning to do unsupervised clustering or use PCA, there are several dedicated tools that cope with large data sets, as commonly encountered in genomic studies.

Now, R (64 bits) handles large data pretty well, and you still have the option to use disk storage instead of RAM access, but see CRAN Task View [High-Performance and Parallel Computing with R][1]. Standard GLM will easily accomodate 20,000 obs. (but see also [speedglm][2]) within reasonable time, as shown below:

    > require(MASS)
    > n <- 20000
    > X <- mvrnorm(n, mu=c(0,0), Sigma=matrix(c(1,.8,.8,1), 2, 2))
    > df <- cbind.data.frame(X, grp=gl(4, n/4), y=sample(c(0,1), n, rep=TRUE))
    > system.time(glm(y ~ ., data=df))
       user  system  elapsed
      0.361   0.018    0.379

To give a more concrete illustration, I used R to process and analyse large genetic data (800 individuals x 800k [SNPs][3], where the main statistical model was a stratified GLM with several covariates (2 min); that was made possible thanks to efficient R and C codes available in the [snpMatrix][4] package (in comparison, the same kind of model took about 8 min using a dedicated C++ software ([plink][5]). I also worked on a clinical study (12k patients x 50 variables of interest) and R fits my needs too. Finally, as far as I know, the [lme4][6] package is the only software that allow to fit mixed-effects model with unbalanced and large data sets (as is the case in large-scale educational assessment).

Stata/SE is another software that can handle [large data set][7]. SAS and SPSS are file based software, so they will handle large volumes of data. A comparative review of software for datamining is available in [Data Mining Tools: Which One is Best for CRM][8]. For visualization, there are also plenty of options; maybe a good start is [Graphics of large datasets: visualizing a million][9] ([reviewed][10] in the JSS by P Murrell), and all related threads on this site.


  [1]: http://cran.r-project.org/web/views/HighPerformanceComputing.html
  [2]: http://cran.r-project.org/web/packages/speedglm/index.html
  [3]: http://www.google.fr/url?sa=t&source=web&cd=2&ved=0CCIQFjAB&url=http%3A%2F%2Fen.wikipedia.org%2Fwiki%2FSingle-nucleotide_polymorphism&rct=j&q=single%20nucleotide%20polymorphisms&ei=hDu4TKyRLJDp4gai8MGNDg&usg=AFQjCNGPTlkC2hY6vz7EXSbJe4_YYrumgw&sig2=sweuWH-AMVYdmg_NT2uX8Q&cad=rja
  [4]: http://www.google.fr/url?sa=t&source=web&cd=1&ved=0CBUQFjAA&url=http%3A%2F%2Fwww.bioconductor.org%2Fpackages%2F2.3%2Fbioc%2Fhtml%2FsnpMatrix.html&rct=j&q=snpMatrix&ei=Qjy4TNDJOIXG4AbD1JHbDQ&usg=AFQjCNFJM_G_MFWKEDrIILpdWh8AVATn4g&sig2=wMAoR3l7SB41EG-Lvx9MOQ&cad=rja
  [5]: http://www.google.fr/url?sa=t&source=web&cd=1&ved=0CBUQFjAA&url=http%3A%2F%2Fpngu.mgh.harvard.edu%2F~purcell%2Fplink%2F&rct=j&q=plink&ei=kDy4TMmgAZTe4AbPwcm9Dg&usg=AFQjCNHI9oFtR2YOxmlkKaGIMkTnNxTbSA&sig2=yWlRajpLg9eCIIOKoqy5hA&cad=rja
  [6]: http://cran.r-project.org/web/packages/lme4/index.html
  [7]: http://www.stata.com/order/new/corp/difference.html
  [8]: http://www.information-management.com/specialreports/20060321/1049954-1.html
  [9]: http://www.springer.com/statistics/statistical+theory+and+methods/book/978-0-387-32906-2
  [10]: http://www.jstatsoft.org/v17/b01/paper
