## [Can cross validation be used for causal inference?](http://stats.stackexchange.com/questions/3893/can-cross-validation-be-used-for-causal-inference)

It seems to me that your question more generally addresses different flavour of validation for a predictive model: Cross-validation has somewhat more to do with *internal validity*, or at least the initial modelling stage, whereas drawing causal links on a wider population is more related to *external validity*. By that (and as an update following @Brett's nice remark), I mean that we usually build a model on a working sample, assuming an hypothetical conceptual model (i.e. we specify the relationships between predictors and the outcome(s) of interest), and we try to obtain reliable estimates with a minimal classification error rate or a minimal prediction error. Hopefully, the better the model performs, the better it will allow us to predict outcome(s) on unseen data; still, CV doesn't tell anything about the "validity" or adequacy of the hypothesized causal links. We could certainly achieve decent results with a model where some moderation and/or mediation effects are neglected or simply not known in advance.

My point is that whatever the method you use to validate your model (and holdout method is certainly not the best one, but still it is widely used in epidemiological study to alleviate the problems arising from stepwise model building), you work with the same sample (which we assume is representative of a larger population). On the contrary, generalizing the results and the causal links inferred this way to new samples or a plausibly related population is usually done by *replication studies*. This ensures that we can safely test the predictive ability of our model in a "superpopulation" which features a larger range of individual variations and may exhibit other potential factors of interest.

Your model might provide valid predictions for your working sample, and it includes all potential confounders you may have think of; however, it is possible that it will not perform as well with new data, just because other factors appear in the intervening causal path that were not identified when building the initial model. This may happen if some of the predictors and the causal links inferred therefrom depend on the particular trial centre where patients were recruited, for example.

In genetic epidemiology, many [genome-wide association studies][1] fail to replicate just because we are trying to model complex diseases with an oversimplified view on causal relationships between DNA markers and the observed phenotype, while it is very likely that gene-gene (epistasis), gene-diseases (pleiotropy), gene-environment, and population substructure all come into play, but see for example [Validating, augmenting and refining genome-wide association signals][2] (Ioannidis et al., Nature Reviews Genetics, 2009 10). So, we can build-up a performant model to account for the observed cross-variations between a set of genetic markers (with very low and sparse effect size) and a multivariate pattern of observed phenotypes (e.g., volume of white/gray matter or localized activities in the brain as observed through fMRI, responses to neuropsychological assessment or personality inventory), still it won't perform as expected on an independent sample.

As for a general reference on this topic, can recommend chapter 17 and Part III of [Clinical Prediction Models][3], from EW Steyerberg (Springer, 2009). I also like the following article from Ioannidis:

> Ioannidis, JPA, [Why Most Published
> Research Findings Are False?][4] PLoS
> Med. 2005 2(8): e124


  [1]: http://en.wikipedia.org/wiki/Genome-wide_association_study
  [2]: http://www.nature.com/nrg/journal/v10/n5/abs/nrg2544.html
  [3]: http://www.clinicalpredictionmodels.org/
  [4]: http://www.ncbi.nlm.nih.gov/pmc/articles/PMC1182327/
