## [How does one do a Type-III SS ANOVA in R with contrast codes?](http://stats.stackexchange.com/questions/4544/how-does-one-do-a-type-iii-ss-anova-in-r-with-contrast-codes)

Type III sum of squares for ANOVA are readily available through the `Anova()` function from the [car][1] package.

Contrast coding can be done in several ways, using `C()`, the `contr.*` family (as indicated by @nico), or directly the `contrasts()` function/argument. This is detailed in §6.2 (pp. 144-151) of *[Modern Applied Statistics with S][2]* (Springer, 2002, 4th ed.). Note that `aov()` is just a wrapper function for the `lm()` function. It is interesting when one wants to control the error term of the model (like in a within-subject design), but otherwise they both yield the same results (and whatever the way you fit your model, you still can output ANOVA or LM-like summaries with `summary.aov` or `summary.lm`). 

I don't have SPSS to compare the two outputs, but something like

    > library(car)
    > sample.data <- data.frame(IV=factor(rep(1:4,each=20)),
                                DV=rep(c(-3,-3,1,3),each=20)+rnorm(80))
    > Anova(lm1 <- lm(DV ~ IV, data=sample.data, 
                      contrasts=list(IV=contr.poly)), type="III")
    Anova Table (Type III tests)
    
    Response: DV
                Sum Sq Df F value    Pr(>F)    
    (Intercept)  18.08  1  21.815  1.27e-05 ***
    IV          567.05  3 228.046 < 2.2e-16 ***
    Residuals    62.99 76                      
    ---
    Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1 

is worth to try in first instance.

About factor coding in R vs. SAS: R considers the baseline or reference level as the first level in lexicographic order, whereas SAS considers the last one. So, to get comparable results, either you have to use `contr.SAS()` or to `relevel()` your R factor.


  [1]: http://cran.r-project.org/web/packages/car/index.html
  [2]: http://www.stats.ox.ac.uk/pub/MASS4/
