## [Find out pseudo R square value for a Logistic Regression analysis](http://stats.stackexchange.com/questions/5293/find-out-pseudo-r-square-value-for-a-logistic-regression-analysis)

Take a look at the `lrm()` function from the [Design](http://cran.r-project.org/web/packages/Design/index.html) package. It features everything you need for fitting GLM. The Hosmer and Lemeshow test has limited power and depends on arbitrary discretization; it is discussed in Harrell, *Regression Modeling Strategies* (p. 231) and on the [R-help][1] mailing-list. There is also a comparison of GoF tests for logistic regression in [A comparison of goodness-of-fit tests for the logistic regression model][3], Stat. Med. 1997 16(9):965.

Here is an example of use:

    library(Design)  # depends on Hmisc
    x1 <- rnorm(500)
    x2 <- rnorm(500)
    L  <- x1+abs(x2)
    y  <- ifelse(runif(500)<=plogis(L), 1, 0)
    f <- lrm(y ~ x1+x2, x=TRUE, y=TRUE)
    resid(f, 'gof')

which yields something like

    Sum of squared errors     Expected value|H0                    SD 
             100.33517914          100.37281429            0.37641975 
                        Z                     P 
              -0.09998187            0.92035872 

but see `help(residuals.lrm)` for additional help.


The following thread contains critical discussions that might also be helpful: Logistic Regression: [Which pseudo R-squared measure is the one to report (Cox & Snell or Nagelkerke)?][2]


  [1]: http://www.biostat.wustl.edu/archives/html/s-news/1999-04/msg00147.html
  [2]: http://stats.stackexchange.com/questions/3559/logistic-regression-which-pseudo-r-squared-measure-is-the-one-to-report-cox-s/
  [3]: http://www.ds.unifi.it/cipollini/GLM/Doc/HHLcL1997_GofFit.pdf

