## [Why is there a difference between manually calculating a logistic regression 95% confidence interval, and using the confint() function in R?](http://stats.stackexchange.com/questions/5304/why-is-there-a-difference-between-manually-calculating-a-logistic-regression-95)

After having fetched the data from the [accompagnying website][1], here is how I would do:

    chdage <- read.table("chdage.dat", header=F, col.names=c("id","age","chd"))
    chdage$aged <- ifelse(chdage$age>=55, 1, 0)
    mod.lr <- glm(chd ~ aged, data=chdage, family=binomial)
    summary(mod.lr)

The 95% CIs based on profile likelihood is obtained with

    require(MASS)
    exp(confint(mod.lr))

This often is the default if package `MASS` is automatically loaded. In this case, I get 

                    2.5 %     97.5 %
    (Intercept) 0.2566283  0.7013384
    aged        3.0293727 24.7013080

Now, if I want to compare with 95% Wald CIs (based on asymptotic normality) like the one you computed by hand, I would use `confint.default()` instead; this yields:

                    2.5 %     97.5 %
    (Intercept) 0.2616579  0.7111663
    aged        2.8795652 22.8614705

Wald CIs are good in most situation, although profile likelihood-based may be useful with complex sampling strategies. If you want to grasp the idea of how they work, here is a brief overview of the main principles: [Confidence intervals by the profile likelihood method, with applications in veterinary epidemiology][2]. You can also take a look at Venables and Ripley's MASS book, §8.4, pp. 220-221.


  [1]: http://www.ats.ucla.edu/stat/Stata/examples/alr2/
  [2]: http://people.upei.ca/hstryhn/stryhn208.pdf
