## [R package for combining factor levels for datamining?](http://stats.stackexchange.com/questions/5656/r-package-for-combining-factor-levels-for-datamining)

It seems it's just a matter of "releveling" the factor; no need to compute partial sums or make a copy of the original vector. E.g.,

    set.seed(101)
    a <- factor(LETTERS[sample(5, 150, replace=TRUE, 
                               prob=c(.1, .15, rep(.75/3,3)))])
    p <- 1/5
    lf <- names(which(prop.table(table(a)) < p))
    levels(a)[levels(a) %in% lf] <- "Other"

Here, the original factor levels are distributed as follows:

     A  B  C  D  E 
    18 23 35 36 38 

and then it becomes

    Other     C     D     E 
       41    35    36    38 

It may be conveniently wrapped into a function. There is a `combine_factor()` function in the [reshape][1] package, so I guess it could be useful too.

Also, as you seem interested in data mining, you might have a look at the [caret][2] package. It has a lot of useful features for data preprocessing, including functions like `nearZeroVar()` that allows to flag predictors with very imbalanced distribution of observed values (See the vignette, [example data, pre-processing functions, visualizations and other functions][3], p. 5, for example of use).


  [1]: http://cran.r-project.org/web/packages/reshape/index.html
  [2]: http://caret.r-forge.r-project.org/Classification_and_Regression_Training.html
  [3]: http://cran.r-project.org/web/packages/caret/vignettes/caretMisc.pdf
