## [What are the practical & interpretation differences between alternatives and logistic regression?](http://stats.stackexchange.com/questions/5912/what-are-the-practical-interpretation-differences-between-alternatives-and-logi)

**Disclaimer:** It is certainly far from being a full answer to the question!

I think there are at least two levels to consider before establishing a distinction between all such methods:

* **whether *a single model is fitted* or not:** This helps opposing methods like logistic regression vs. RF or [Gradient Boosting][1] (or more generally [Ensemble methods][2]), and also put emphasis on parameters estimation (with associated asymptotic or bootstrap confidence intervals) vs. classification or prediction accuracy computation;
* **whether *all variables are considered* or not:** This is the basis of feature selection, in the sense that penalization or regularization allows to cope with "irregular" data sets (e.g., large $p$ and/or small $n$) and improve generalizability of the findings.

Here are few other points that I think are relevant to the question.

In case we consider several models--the same model is fitted on different subsets (individuals and/or variables) of the available data, or different competitive models are fitted on the same data set--, [cross-validation][3] can be used to avoid overfitting and perform model or feature selection, although CV is not limited to this particular cases (it can be used with [GAMs][4] or penalized GLMs, for instance). Also, there is the traditional interpretation issue: more complex models often implies more complex interpretation (more parameters, more stringent assumptions, etc.).

Gradient boosting and RFs overcome the limitations of a single decision tree, thanks to [Boosting][5] whose main idea is to combine the output of several weak learning algorithms in order to build a more accurate and stable decision rule, and [Bagging][6] where we "average" results over resampled data sets. Altogether, they are often viewed as some kind of black boxes in comparison to more "classical" models where clear specifications for the model are provided (I can think of three classes of models: [parameteric][7], [semi-parametric][8], [non-parametric][9]), but I think the discussion held under this other thread [The Two Cultures: statistics vs. machine learning?][10] provide interesting viewpoints.

Here are a couple of papers about feature selection and some ML techniques:

1. Saeys, Y, Inza, I, and Larrañaga, P. [A review of feature selection techniques in bioinformatics][11], Bioinformatics (2007) 23(19): 2507-2517.
2. Dougherty, ER, Hua J, and Sima, C. [Performance of Feature Selection Methods][12], Current Genomics (2009) 10(6): 365–374.
3. Boulesteix, A-L and Strobl, C. [Optimal classifier selection and negative bias in error rate estimation: an empirical study on high-dimensional prediction][13], BMC Medical Research Methodology (2009) 9:85.
4. Caruana, R and Niculescu-Mizil, A. [An Empirical Comparison of Supervised Learning Algorithms][14]. Proceedings of the 23rd International Conference on Machine Learning (2006).
5. Friedman, J, Hastie, T, and Tibshirani, R. [Additive logistic regression: A statistical view of boosting][15],  Ann. Statist. (2000) 28(2):337-407. (With discussion)
6. Olden, JD, Lawler, JJ, and Poff, NL. [Machine learning methods without tears: a primer for ecologists][16], Q Rev Biol. (2008) 83(2):171-93.

And of course, [The Elements of Statistical Learning][17], by Hastie and coll., is full of illustrations and references. Also be sure to check the [Statistical Data Mining Tutorials][18], from Andrew Moore.


  [1]: http://en.wikipedia.org/wiki/Gradient_boosting
  [2]: http://en.wikipedia.org/wiki/Ensemble_learning
  [3]: http://en.wikipedia.org/wiki/Cross-validation_%28statistics%29
  [4]: http://en.wikipedia.org/wiki/Generalized_additive_model
  [5]: http://en.wikipedia.org/wiki/Boosting
  [6]: http://en.wikipedia.org/wiki/Bootstrap_aggregating
  [7]: http://en.wikipedia.org/wiki/Parametric_model
  [8]: http://en.wikipedia.org/wiki/Semiparametric_model
  [9]: http://en.wikipedia.org/wiki/Non-parametric_model
  [10]: http://stats.stackexchange.com/questions/6/the-two-cultures-statistics-vs-machine-learning
  [11]: http://bioinformatics.oxfordjournals.org/content/23/19/2507.abstract
  [12]: http://www.ncbi.nlm.nih.gov/pmc/articles/PMC2766788/
  [13]: http://www.biomedcentral.com/1471-2288/9/85/abstract
  [14]: http://www.cs.cornell.edu/~caruana/ctp/ct.papers/caruana.icml06.pdf
  [15]: http://projecteuclid.org/DPubS?service=UI&version=1.0&verb=Display&handle=euclid.aos/1016218223
  [16]: http://www.fish.washington.edu/research/oldenlab/pdf/2008/QuarterReviewBiol_2008.pdf
  [17]: http://www-stat.stanford.edu/~tibs/ElemStatLearn/
  [18]: http://www.autonlab.org/tutorials/
