## [In genome wide association studies, what are Principal Components?](http://stats.stackexchange.com/questions/8777/in-genome-wide-association-studies-what-are-principal-components)

In this particular context, PCA is mainly used to account for population-specific variations in alleles distribution on the SNPs (or other DNA markers, although I'm only familiar with the SNP case) under investigation. Such "population substructure" mainly arises as a consequence of varying frequencies of minor alleles in genetically distant ancestries (e.g. japanese and black-african or european-american). The general idea is well explained in [Population Structure and Eigenanalysis][1], by Patterson et al. (*PLoS Genetics* 2006, 2(12)), or the *Lancet*'s special issue on genetic epidemiology (2005, 366; most articles can be found on the web, start with Cordell & Clayton, [Genetic Association Studies][2]).

The construction of principal axes follows from the classical approach to PCA, which is applied to the scaled matrix (individuals by SNPs) of observed genotypes (AA, AB, BB; say B is the minor allele in all cases), to the exception that an additional normalization to account for population drift might be applied. It all assumes that the frequency of the minor allele (taking value in {0,1,2}) can be considered as numeric, that is we work under an *additive model* (also called allelic dosage) or any equivalent one that would make sense. As the successive orthogonal PCs will account for the maximum variance, this provides a way to highlight groups of individuals differing at the level of minor allele frequency. The software used for this is known as [Eigenstrat][3]. It is worth to note that other methods to detect population substructure were proposed, in particular model-based cluster reconstruction (see references at the end). More information can be found by browsing the [Hapmap][4] project, and available tutorial coming from the [Bioconductor](http://www.bioconductor.org) project. (Search for Vince J Carey or David Clayton's nice tutorials on Google).

Considering that eigenanalysis allows to uncover some structure at the level of the individuals, we can use this information when trying to explain observed variations in a given phenotype (or any distribution that might be defined according to a binary criterion, e.g. disease or case-control situation). Specifically, we can adjust our analysis with those PCs (i.e., the factor scores of individuals), as illustrated in [Principal components analysis corrects for stratification in genome-wide association studies][5], by Price et al. (*Nature Genetics* 2006, 38(8)), and later work (there was a nice picture showing axes of genetic variation in Europe, but I can't find it actually). Note also that another solution is to carry out a stratified analysis (by including ethnicity in an GLM)--this is readily available in the [snpMatrix][6] package, for example.

**References**

1. Daniel Falush, Matthew Stephens, and Jonathan K Pritchard (2003). [Inference of population structure using multilocus genotype data: linked loci and correlated allele frequencies][7]. *Genetics*, 164(4): 1567–1587.
2. B Devlin and K Roeder (1999). [Genomic control for association studies][8]. *Biometrics*, 55(4): 997–1004.
3. JK Pritchard, M Stephens, and P Donnelly (2000). [Inference of population structure using multilocus genotype data][9]. *Genetics*, 155(2): 945–959.
4. Gang Zheng, Boris Freidlin, Zhaohai Li, and Joseph L Gastwirth (2005). [Genomic control for association studies under various genetic models][10].	*Biometrics*, 61(1): 186–92.	
5. Chao Tian, Peter K. Gregersen, and Michael F. Seldin1 (2008). [Accounting for ancestry: population substructure and genome-wide association studies][11]. *Human Molecular Genetics*, 17(R2): R143-R150.
6. Kai Yu, [Population Substructure and Control Selection in Genome-wide Association Studies][12].
7. Alkes L. Price, Noah A. Zaitlen, David Reich and Nick Patterson (2010). [New approaches to population stratification in genome-wide association studies][13], *Nature Reviews Genetics*
8. Chao Tian, et al. (2009). [European Population Genetic Substructure: Further Definition of Ancestry Informative Markers for Distinguishing among Diverse European Ethnic Groups][14], Molecular Medicine, 15(11-12): 371–383.


  [1]: http://www.genome.duke.edu/education/seminars/journal-club/documents/PopStructure.pdf
  [2]: http://www.molmed.nl/uploads/abstracts/127/Lancet%20genetic%20epi%203.pdf
  [3]: http://genepath.med.harvard.edu/~reich/Software.htm
  [4]: http://hapmap.ncbi.nlm.nih.gov/
  [5]: http://www.biostat.jhsph.edu/~iruczins/teaching/misc/gwas/papers/price2006.pdf
  [6]: http://www.bioconductor.org/packages/2.3/bioc/html/snpMatrix.html
  [7]: http://pritch.bsd.uchicago.edu/software/FalushEtAl03.pdf
  [8]: http://www.biostat.jhsph.edu/~iruczins/teaching/misc/gwas/papers/devlin1999.pdf
  [9]: http://pritch.bsd.uchicago.edu/publications/structure.pdf
  [10]: http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.167.8448&rep=rep1&type=pdf
  [11]: http://www.ncbi.nlm.nih.gov/pubmed/18852203
  [12]: http://biowulf.nih.gov/symposium/slides/Kai_Yu.pdf
  [13]: http://genetics.med.harvard.edu/reich/Reich_Lab/Publications_files/2010_Price_stratificationreview.pdf
  [14]: http://www.ncbi.nlm.nih.gov/pmc/articles/PMC2730349/
