## [Multiple comparisons with ANOVA including one between and one within-subject effect](http://stats.stackexchange.com/questions/19571/multiple-comparisons-with-anova-including-one-between-and-one-within-subject-eff)

The `lme()` function, from the [nlme][1] package (or see the [companion website](http://stat.bell-labs.com/project/nlme/)), allows to fit mixed-effects models with gaussian errors. For an alternative framework, see this question: [How to choose nlme or lme4 R library for mixed effects models?][2] Your formula reads as follows: your model includes a between- by within-subject interaction assuming [compound symmetry](http://stats.stackexchange.com/q/15102/930) for the variance-covariance structure; subjects are considered random effects (in other words, this is a varying intercept model, as symbolized by the `~1|ID` formula for the `random` term). The `type="marginal"` argument indicates that you want to compute Type III sum of squares for fixed effects. (See [this](http://stats.stackexchange.com/q/11209/930) or [this](http://stats.stackexchange.com/q/4544/930) question for issues with the different types of SSs, and discussion on the UCLA server on [How can I get Type III tests of fixed effects in R?][3]) This corresponds to what would be obtained using `aov()` with the appropriate error term (see the corresponding section in [Notes on the use of R for psychology experiments and questionnaires][4]). More details about R's formulas can be found on our [R's lmer cheat-sheet][5].

For more information, you can refer to:

* John Fox's appendix on [Linear Mixed Models][6] (2002).
* A nice guide to [R: Analysis of variance (ANOVA)][7], full of illustrations for various experimental designs, which uses the [ez][8] package.
* Another tutorial on [Multilevel Linear Model][9]
* The [GLMM wiki][10], which summarizes the main issues raised on [r-sig-mixed-models][11] mailing-list.

(And if you have some background in psychology, I'd recommend [*Practical Data Analysis for the Language Sciences with R*](http://magnuson.psy.uconn.edu/mirman/R/Baayen.pdf), by Baayen, which has a lot of illustrations on the analysis of crossed effects in psycholinguistic; there's also a R package, [languageR][12].)

Finally, as you can see a lot has been discussed in related threads so it's worth browsing the [tag:repeated-measures] or [tag:mixed-model] tags. I'd also like to put a direct link to a related thread that might be of interest: [Why do lme and aov return different results for repeated measures ANOVA in R?][13]


  [1]: http://cran.r-project.org/web/packages/nlme/index.html
  [2]: http://stats.stackexchange.com/q/5344/930
  [3]: http://www.ats.ucla.edu/stat/r/faq/type3.htm
  [4]: http://www.psych.upenn.edu/~baron/rpsych/rpsych.html
  [5]: http://stats.stackexchange.com/q/13166/930
  [6]: http://cran.r-project.org/doc/contrib/Fox-Companion/appendix-mixed-models.pdf
  [7]: http://egret.psychol.cam.ac.uk/statistics/R/anova.html
  [8]: http://cran.r-project.org/web/packages/ez/index.html
  [9]: http://yatani.jp/HCIstats/MultilevelLinear
  [10]: http://glmm.wikidot.com/faq
  [11]: https://stat.ethz.ch/pipermail/r-sig-mixed-models/
  [12]: http://cran.r-project.org/web/packages/languageR/index.html
  [13]: http://stats.stackexchange.com/q/14088/930
