## [How can I draw a boxplot without boxes in R?](http://stats.stackexchange.com/questions/21370/how-can-i-draw-a-boxplot-without-boxes-in-r)

One interesting application of R's `stripchart()` is that you can use jittering or stacking when there is some overlap in data points (see `method=`).
With [lattice](http://lmdvr.r-forge.r-project.org), the corresponding function is `stripplot()`, but it lacks the above method argument to separate coincident points (but see below fo one way to achieve stacking).

An alternative way of doing what you want is to use Cleveland's dotchart. Here are some variations around this idea using `lattice`:

    my.df <- data.frame(x=sample(rnorm(100), 100, replace=TRUE), 
                        g=factor(sample(letters[1:2], 100, replace=TRUE)))
    library(lattice)
    dotplot(x ~ g, data=my.df)               # g on the x-axis
    dotplot(g ~ x, data=my.df, aspect="xy")  # g on the y-axis
    ## add some vertical jittering (use `factor=` to change its amount in both case)
    dotplot(g ~ x, data=my.df, jitter.y=TRUE)  
    stripplot(g ~ x, data=my.df, jitter.data=TRUE)  
    ## use stacking (require the `HH` package)
    stripplot(g ~ x, data=my.df, panel=HH::panel.dotplot.tb, factor=.2)
    ## using a custom sunflowers panel, available through
    ## http://r.789695.n4.nabble.com/ Grid- graphics- issues- tp797307p797307.html
    stripplot(as.numeric(g) ~ x, data=my.df, panel=panel.sunflowerplot, 
              col="black", seg.col="black", seg.lwd=1, size=.08)
    ## with overlapping data, it is also possible to use transparency
    dotplot(g ~ x, data=my.df, aspect=1.5, alpha=.5, pch=19)

Some previews of the above commands:


![enter image description here][1]


  [1]: http://i.stack.imgur.com/lX07Z.png
