## [How to highlight predefined groups in PCA individual map?](http://stats.stackexchange.com/questions/24450/how-to-highlight-predefined-groups-in-pca-individual-map)

Let me continue my comment with an illustration for the case where you're interested in existing R packages. There are several package in the [Multivariate][1] Task View that will provide enhanced method for PCA-related methods (as compared to R base `prcomp` and `princomp`), *e.g.* [ade4][2] or [FactorMineR][3]. I personally like FactoMineR because of its simple syntax, and you check the [associated website][4] for more information on the available methods.

One can use supplementary categorical and/or numerical variables when applying a PCA. Those variables are not used to construct factor axes, but can be showed afterwards on the correlation circle (for numerical variables) or the individual map (for categorical variables). Here is a toy example of use (from the on-line help):

     data(decathlon)
     res.pca <- PCA(decathlon, quanti.sup = 11:12, quali.sup=13)
     plotellipses(res.pca,13)
     
![enter image description here][5]

If you have multiple passive variables, you can select the one to display (with or without confidence ellipses) using the `keepvar=` argument. Here is another picture with two illustrative variables.

![enter image description here][6]

Be careful with arguments that are a little bit non-standard if you are used to default plotting functions in R. The `plotellipses()` function makes use of the helper function `ellipse::ellipse` that you can use (or not) in any plot (look for `monpanel.ellipse` subfunction in `plotellipses()` to see how confidence lines are computed). That's what I did to build specific individual map (B&W, different plotting symbol, etc.). For example, the following snippet just plot all individuals with two different symbols depending on the type of sporting event (2004 Olympic Game or 2004 Decastar):

    labs <- paste(round(res.pca$eig[1:2, 2], 2), "%", sep="")
    plot(res.pca$ind$coord[,1:2], pch=as.numeric(decathlon$Competition),
         xlab=paste("Dim. 1 (", labs[1], ")", sep=""), 
         ylab=paste("Dim. 2 (", labs[2], ")", sep=""))
    abline(v=0, h=0, lty=2)
    
Besides, I would like to point you to @vqv's excellent [ggbiplot][7] package, available on GitHub, which follows from [one of his answer][8]. (It uses R base functions and ggplot2.)


  [1]: http://cran.r-project.org/web/views/Multivariate.html
  [2]: http://cran.r-project.org/web/packages/ade4/index.html
  [3]: http://cran.r-project.org/web/packages/FactoMineR/index.html
  [4]: http://factominer.free.fr/
  [5]: http://i.stack.imgur.com/CeZED.png
  [6]: http://i.stack.imgur.com/OD4op.png
  [7]: https://github.com/vqv/ggbiplot
  [8]: http://stats.stackexchange.com/a/7862/930
